@@ -107,7 +107,13 @@ def validations(
         lims_id,
         "dev",
     )
-    console.print(from_AssetValidationResult(validation) for validation in validations)
+    if not len(validations) > 0:
+        console.print("No validations found for lims_id=%s" % lims_id)
+        return
+
+    console.print("Found validations:")
+    for validation in validations:
+        console.print(from_AssetValidationResult(validation))
 
 
 if __name__ == "__main__":
