@@ -14,4 +14,8 @@ def resolve_local_filepath(glob_pattern: str, local_dir: str) -> str:
     if len(resolved) > 1:
         # logger.info("Multiple files globbed: %s" % resolved)  # todo add logging
         raise Exception("Multiple files globbed: %s" % resolved)
+    if len(resolved) != 0:
+        raise Exception(
+            "No files globbed for glob_pattern=%s local_dir=%s", glob_pattern, local_dir
+        )
     return resolved[0]
